import sys
import time
from pprint import pprint
import re

from selenium import webdriver
from selenium.webdriver.chrome.options import Options
from selenium.webdriver.common.by import By

class RemoteUi:
	#ROBOT_LIBRARY_SCOPE = 'TEST SUITE'
	ROBOT_LIBRARY_SCOPE = 'GLOBAL'
	def __init__(self, ip, port=80, headless=True):
		self.ip = ip
		self.chrome_options = Options()
		if headless:
			self.chrome_options.add_argument("--headless")
		self.chrome_options.add_experimental_option("detach", True)
		self.chrome_options.add_argument("--disable-infobars")
		self.chrome_options.add_argument("--disable-gpu")
		self.chrome_options.add_argument("--no-sandbox")
		self.driver = webdriver.Chrome('chromedriver', options=self.chrome_options)
		self.driver.implicitly_wait(3)
		self.driver.set_window_size(1280, 960)
		self.ui_loaded = False

	def load_ui(self):
		if not self.ui_loaded:
			self.driver.get("http://"+self.ip)
			self.ui_loaded = True

	def location_should_start_with(self, url):
		m=re.match(r'^{0}'.format(url), self.driver.current_url)
		assert m, "Location is {0}, expected {1}".format(self.driver.current_url, url)

	def take_screenshot(self, name):
		self.driver.save_screenshot(name+".png")

	def click_on(self, element):
		if element[0] != "/":
			self.driver.find_element_by_css_selector(element).click()
		else:
			self.driver.find_element_by_xpath(element).click()
		time.sleep(0.3)

	def is_visible(self, element):
		e = None
		if element[0] != "/":
			e = self.driver.find_element_by_css_selector(element)
		else:
			e = self.driver.find_element_by_xpath(element)
		return e.is_displayed()

	def is_enabled(self, element):
		e = None
		if element[0] != "/":
			e = self.driver.find_element_by_css_selector(element)
		else:
			e = self.driver.find_element_by_xpath(element)
		return e.get_attribute("disabled") == None

	def click_ok(self, dialog):
		self.click_on("div[aria-describedby=\"" + dialog + "\"] div[class*=\"ui-dialog-buttonpane\"] button[role=\"button\"]")

	def go_to_page(self, page):
		pages = {'Clone': "div#navbtn_clone",
				 'Image': "div#navbtn_clone",
				 'Hash': "div#navbtn_hash",
				 'Wipe': "div#navbtn_wipe",
				 'Push': "div#navbtn_push",
				 'Task Macro': "div#navbtn_task_macro",
				 'File Browser': "div#navbtn_file_browser",
				 'Logs': "div#navbtn_logs",
				 'Statistics': "div#navbtn_stats",
				 'Manage Repositories': "div#navbtn_manage_repos",
				 'System Settings': "div#navbtn_settings",
				 'Network Settings': "div#navbtn_network_settings",
				 'Software Updates': "div#navbtn_software",
				 'Power Off': "div#navbtn_restart"}
		element = pages[page]
		dirxn = 'down'
		i = 4
		while i > 0:
			if self.driver.find_element_by_css_selector(element).is_displayed():
				break
			if self.driver.find_element_by_css_selector("div#navbtn_restart").is_displayed():
				dirxn = 'up'
				i = 4
			self.click_on("div#nav_"+dirxn)
			i -= 1
		if self.driver.find_element_by_css_selector(element).is_displayed():
			self.click_on(element)
	
	def get_op_page(self, op):
		pages = {'Clone': "clone",
				 'Image': "clone",
				 'Hash': "hash",
				 'Wipe': "wipe",
				 'Push': "push"
		}
		return pages[op]

	def delete_all_tasks(self, op):
		self.go_to_page(op)
		page = self.get_op_page(op)
		for i in range(4, -1, -1):
			task = 'div#{0}_tab_{1}'.format(page, i)
			if self.driver.find_element_by_css_selector(task).is_displayed():
				self.click_on(task)
				self.click_on("div#" + page + "_delete_btn")
				self.click_ok(page + "_delete_dialog")
			else:
				pprint('{0}: not displayed?'.format(task))

	def add_tasks(self, op, num=1):
		self.go_to_page(op)
		page = self.get_op_page(op)
		for i in range(0, num):
			self.click_on("div#" + page + "_add_btn")

	def go_to_task(self, task):
		t = task.split(':')
		self.go_to_page(t[0])
		page = self.get_op_page(t[0])
		tab = 'div#{0}_tab_{1}'.format(page, int(t[1])-1)
		if self.driver.find_element_by_css_selector(tab).is_displayed():
			self.click_on(tab)

	def select_drives(self, op, type, filter=None):
		page = self.get_op_page(op)
		if isinstance(filter, list):
			filter = '|'.join(filter)
		pprint("select_drives: filter='{0}'".format(filter))
		self.click_on("div#{0}_{1}_btn".format(page, type.lower()))
		time.sleep(2)
		table = self.driver.find_element_by_id('clone_{0}_select'.format(type.lower()))
		rows = table.find_elements_by_class_name("select_row")
		for row in rows:
			col = row.find_elements(By.TAG_NAME, "td")[0]
			if filter:
				regx = re.compile(filter.upper())
				if regx.match(col.text) is None:
					print("Skipping: " + col.text)
					continue
			while not row.is_displayed():
				self.click_on("div[aria-describedby=\"clone_{0}_dialog\"] > div + div > div > div > div + div > a.mCSB_buttonDown".format(type.lower()))

			row.click()
		self.click_ok("clone_{0}_dialog".format(type.lower()))

	def is_task_running(self, task):
		self.go_to_task(task)
		prog = self.driver.find_element_by_css_selector("div#clone_progressbar_info")
		if not prog.is_displayed():
			return False
		pprint(prog.text)
		return prog.text not in ['COMPLETED', 'ERROR', 'ABORTED']

	def wait_for_tasks(self, tasks):
		n = len(tasks)
		done = 0
		while done < n:
			done = 0
			time.sleep(2)
			for task in tasks:
				if self.is_task_running(task) is False:
					done += 1
				time.sleep(3)

	def select_repositories(self, op, type, filter=None):
		page = self.get_op_page(op)
		if isinstance(filter, list):
			filter = '|'.join(filter)
		pprint("select_repositories: filter='{0}'".format(filter))
		self.click_on("div#{0}_{1}_btn".format(page, type.lower()))
		time.sleep(2)
		table = self.driver.find_element_by_id('clone_{0}_repo_select'.format(type.lower()))
		rows = table.find_elements_by_class_name("select_row")
		for row in rows:
			col = row.find_elements(By.TAG_NAME, "td")[0]
			if filter:
				regx = re.compile(filter.upper())
				if regx.match(col.text) is None:
					print("Skipping: " + col.text)
					continue
			while not row.is_displayed():
				self.click_on("div[aria-describedby=\"clone_{0}_repo_dialog\"] > div + div > div > div > div + div > a.mCSB_buttonDown".format(type.lower()))

			row.click()
		self.click_ok("clone_{0}_repo_dialog".format(type.lower()))

	def get_task_status(self, task):
		self.go_to_task(task)
		prog = self.driver.find_element_by_css_selector("div#clone_progressbar_info")
		if not prog.is_displayed():
			return 'NONE'
		return prog.text
